@@ -1,7 +1,7 @@
 """Main module."""
 from datetime import datetime, timedelta
 import logging
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 from aiohttp import ClientConnectionError, ClientResponseError, ClientSession
 
@@ -112,8 +112,8 @@ class ClimaCell:
     def __init__(
         self,
         apikey: str,
-        latitude: str,
-        longitude: str,
+        latitude: Union[int, float, str],
+        longitude: Union[int, float, str],
         unit_system: str = "us",
         session: ClientSession = None,
     ) -> None:
@@ -122,8 +122,8 @@ class ClimaCell:
             raise ValueError("`unit_system` must be `si` or `us`")
 
         self.apikey = apikey
-        self.latitude = latitude
-        self.longitude = longitude
+        self.latitude = str(latitude)
+        self.longitude = str(longitude)
         self.unit_system = unit_system.lower()
         self.session = session
         self.params = {
@@ -155,22 +155,48 @@ class ClimaCell:
                     raise_for_status=True,
                 )
                 return await resp.json()
-        except ClientResponseError as e:
-            if e.status == 400:
-                raise MalformedRequestException(e.request_info, e.history, status=e.status, message=e.message)
-            elif e.status == 401 or e.status == 403:
-                raise InvalidAPIKeyException(e.request_info, e.history, status=e.status, message=e.message)
-            elif e.status == 429:
-                raise RateLimitedException(e.request_info, e.history, status=e.status, message=e.message)
+        except ClientResponseError as error:
+            if error.status == 400:
+                raise MalformedRequestException(
+                    error.request_info,
+                    error.history,
+                    status=error.status,
+                    message=error.message,
+                )
+            elif error.status in (401, 403):
+                raise InvalidAPIKeyException(
+                    error.request_info,
+                    error.history,
+                    status=error.status,
+                    message=error.message,
+                )
+            elif error.status == 429:
+                raise RateLimitedException(
+                    error.request_info,
+                    error.history,
+                    status=error.status,
+                    message=error.message,
+                )
             else:
-                raise UnknownException(e.request_info, e.history, status=e.status, message=e.message)
-        except ClientConnectionError as e:
-            raise CantConnectException(*e.args)
+                raise UnknownException(
+                    error.request_info,
+                    error.history,
+                    status=error.status,
+                    message=error.message,
+                )
+        except ClientConnectionError as error:
+            raise CantConnectException(*error.args)
 
-    def availabile_fields(self, endpoint: str) -> List[str]:
+    @staticmethod
+    def availabile_fields(endpoint: str) -> List[str]:
         "Return available fields for a given endpoint."
         return [field for field in FIELDS if endpoint in FIELDS[field]]
 
+    @staticmethod
+    def first_field(endpoint:  str) -> List[str]:
+        "Return available fields for a given endpoint."
+        return [ClimaCell.availabile_fields(endpoint)[0]]
+
     async def realtime(self, fields: List[str]) -> Dict[str, Any]:
         """Return realtime weather conditions from ClimaCell API."""
         return await self._call_api(
